@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojolicious::Script::Mojo;
 
@@ -7,7 +7,7 @@ use warnings;
 
 use base 'Mojo::Scripts';
 
-__PACKAGE__->attr('description', chained => 1, default => <<'EOF');
+__PACKAGE__->attr(description => (chained => 1, default => <<'EOF'));
 * Access Mojo scripts. *
 Forwards options to the original Mojo scripts,
 will list available scripts by default.
@@ -48,4 +48,4 @@ and implements the following new ones.
 
 L<Mojolicious::Script::Mojo> inherits all methods from L<Mojo::Scripts>.
 
-=cut
\ No newline at end of file
+=cut
